import { FormatValues, ImageLoaderTransformationProps, QualityValues } from './loaders/types';
export declare const VALID_UPLOADCARE_CDN_URLS: string;
export declare const VALID_CDN_URLS: string[];
export declare const loadingValues: readonly ["lazy", "eager", "preload", "lazy-polyfill"];
export declare type LoadingValues = typeof loadingValues[number];
export declare const srcValues: string[];
export declare const fetchPriorityValues: readonly ["high", "low", "auto"];
export declare type FetchPriorityValues = typeof fetchPriorityValues[number];
export declare type ImageParams = {
    width?: string;
    height?: string;
    crop?: string;
    format?: FormatValues;
    quality?: QualityValues;
    loading?: LoadingValues;
    src?: string;
    fetchPriority?: FetchPriorityValues;
};
export declare type ImageParamValidation = {
    matches: RegExp;
    validValue: string;
    loose: boolean;
};
export declare function getImageSrc(src: string, params: ImageLoaderTransformationProps): string;
export declare function getSrcSet(src: string, params: Omit<ImageParams, 'src' | 'width' | 'height'>): string;
export declare function isValidSrc(src: string): boolean;
export declare function isClient(): boolean;
export declare function supportsLazyLoading(): boolean;
export declare const LAZY_POLYFILL_KEY = "lazy-polyfill";
export declare function getClassName(loading: LoadingValues, className?: string): string;
export declare function getImageLoadingProp(loading: LoadingValues): {
    loading: Extract<LoadingValues, 'lazy' | 'eager'>;
};
export declare function getSrcProps({ loading, src, srcSet, sizes, hasMounted, }: {
    loading: LoadingValues;
    src: string;
    srcSet?: string;
    sizes?: string;
    hasMounted: boolean;
}): {
    src: string;
    sizes?: string | undefined;
    srcSet?: string | undefined;
} | {
    'data-sizes'?: string | undefined;
    'data-srcset'?: string | undefined;
    'data-src': string;
};
